pyOpenSSL - necessario para a biblioteca Requests.

# Historico de versoes:

1.3.3: # BUG FIX

1.3.2: # correção para futuro warning

1.3.1: # BUG FIX

1.3.0: Atualização das bibliotecas request, lxml e pyOpenSSL. 
Foi reescrito o módulo de recorrências para acrescentar campos 
de identificação do cliente.

1.2.3: Adicionado resource para editar recorrências. 
Foi removido por falta de implantação da maxipago - erro interno.

1.2.2: # BUG FIX

1.2.1: Adicionado resource para consulta de transactions.

1.2.2: #BUG FIX

1.2.1: Adicionado recurso para alteração de recorrencia

1.2.0: Criacao e adicao de resource para cancelamento de recorrencia.

1.1.9: Foi retirado o caracter com acento (ascii invalido) deste documento.

1.1.8: #BUG FIX

1.1.7: #BUG FIX

1.1.6: Adicao do certificado "pyOpenSSL" para a biblioteca Requests

1.1.5: Adicionado um resource para o retorno da recorrencia.

1.1.4: Atualizacao da biblioteca Requests

1.1.3: #BUG FIX

1.1.2: Adicao de desconto, multa e juros para geracao de boletos.
